/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer.jxmap.map;

import java.awt.Point;
import javax.swing.JPopupMenu;
import nl.cloudfarming.client.geoviewer.Geometrical;
import nl.cloudfarming.client.geoviewer.Layer;
import nl.cloudfarming.client.geviewer.render.GeometricalWidget;
import nl.cloudfarming.client.geoviewer.jxmap.render.JXMapGeoTranslator;
import org.netbeans.api.visual.action.ActionFactory;
import org.netbeans.api.visual.action.PopupMenuProvider;
import org.netbeans.api.visual.widget.Widget;
import org.openide.nodes.Node;
import org.openide.util.Utilities;

/**
 *
 * @author Timon Veenstra
 */
public class MapWidgetFactory {
    
    
    
    static Widget createWidgetFromNode(final Node node, MapScene scene){
        Geometrical geometrical = node.getLookup().lookup(Geometrical.class);
        Layer layer = node.getParentNode().getLookup().lookup(Layer.class);
        
        if (geometrical == null || layer == null || scene.getObjects().contains(node)) {
            return null;
        }
        GeometricalWidget widget = new GeometricalWidget(scene,new JXMapGeoTranslator(scene.getMapViewer()), geometrical, layer.getPalette(),null);

        widget.getActions().addAction(scene.createObjectHoverAction());
        widget.getActions().addAction(scene.createWidgetHoverAction());
        widget.getActions().addAction(scene.createSelectAction());

        widget.getActions().addAction(ActionFactory.createPopupMenuAction(new PopupMenuProvider() {

            @Override
            public JPopupMenu getPopupMenu(Widget widget, Point localLocation) {
                JPopupMenu menu = Utilities.actionsToPopup(node.getActions(true), node.getLookup());
                return menu;
            }
        }));
        return widget;
    }
}
